@@ -156,7 +156,8 @@ void FbActions::set_status(QString status)
     url.setPath("/me/feed");
     qDebug()<<"about to set status with url: "<<url.toString();
     QNetworkRequest req(url);
-    QString post_data = QString("access_token=%1&message=%2").arg(token,status);
+    QString encodedStatus(QUrl::toPercentEncoding(status,"",""));
+    QString post_data = QString("access_token=%1&message=%2").arg(token,encodedStatus);
     qDebug()<<"using post data: "<<post_data;
     access_manager.post(req,post_data.toAscii());
 }
